@@ -1,6 +1,6 @@
 import os
 import tempfile
-from datetime import datetime
+from datetime import datetime, timedelta
 from typing import TYPE_CHECKING, List, Optional, Union
 from urllib.parse import urlparse, urlunparse
 
@@ -8,7 +8,6 @@ from feast.config import Config
 from feast.data_format import ParquetFormat
 from feast.data_source import BigQuerySource, DataSource, FileSource, KafkaSource
 from feast.feature_table import FeatureTable
-from feast.staging.entities import create_bq_view_of_joined_features_and_entities
 from feast.staging.storage_client import get_staging_client
 from feast.value_type import ValueType
 from feast_spark.constants import ConfigOptions as opt
@@ -254,6 +253,65 @@ def replace_bq_table_with_joined_view(
     )
 
 
+def table_reference_from_string(table_ref: str):
+    """
+    Parses reference string with format "{project}:{dataset}.{table}" into bigquery.TableReference
+    """
+    from google.cloud import bigquery
+
+    project, dataset_and_table = table_ref.split(":")
+    dataset, table_id = dataset_and_table.split(".")
+    return bigquery.TableReference(
+        bigquery.DatasetReference(project, dataset), table_id
+    )
+
+
+def create_bq_view_of_joined_features_and_entities(
+    source: BigQuerySource, entity_source: BigQuerySource, entity_names: List[str]
+) -> BigQuerySource:
+    """
+    Creates BQ view that joins tables from `source` and `entity_source` with join key derived from `entity_names`.
+Returns BigQuerySource with reference to created view. The BQ view will be created in the same BQ dataset as `entity_source`.
+    """
+    from google.cloud import bigquery
+
+    bq_client = bigquery.Client()
+
+    source_ref = table_reference_from_string(source.bigquery_options.table_ref)
+    entities_ref = table_reference_from_string(entity_source.bigquery_options.table_ref)
+
+    destination_ref = bigquery.TableReference(
+        bigquery.DatasetReference(entities_ref.project, entities_ref.dataset_id),
+        f"_view_{source_ref.table_id}_{datetime.now():%Y%m%d%H%M%s}",
+    )
+
+    view = bigquery.Table(destination_ref)
+
+    join_template = """
+    SELECT source.* FROM
+    `{entities.project}.{entities.dataset_id}.{entities.table_id}` entities
+    JOIN
+    `{source.project}.{source.dataset_id}.{source.table_id}` source
+    ON
+    ({entity_key})"""
+
+    view.view_query = join_template.format(
+        entities=entities_ref,
+        source=source_ref,
+        entity_key=" AND ".join([f"source.{e} = entities.{e}" for e in entity_names]),
+    )
+    view.expires = datetime.now() + timedelta(days=1)
+    bq_client.create_table(view)
+
+    return BigQuerySource(
+        event_timestamp_column=source.event_timestamp_column,
+        created_timestamp_column=source.created_timestamp_column,
+        table_ref=f"{view.project}:{view.dataset_id}.{view.table_id}",
+        field_mapping=source.field_mapping,
+        date_partition_column=source.date_partition_column,
+    )
+
+
 def start_offline_to_online_ingestion(
     client: "Client",
     project: str,
